@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2005 Kenneth J. Pronovici.
+# Copyright (c) 2004-2006 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -27,11 +27,10 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: peer.py 750 2005-04-18 19:25:23Z pronovic $
+# Revision : $Id: peer.py 1177 2007-03-25 15:20:28Z pronovic $
 # Purpose  : Provides backup peer-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
-# This file was created with a width of 132 characters, and NO tabs.
 
 ########################################################################
 # Module documentation
@@ -57,13 +56,13 @@ Provides backup peer-related objects and utility functions.
 import os
 import logging
 import shutil
-import tempfile
 import sets
 import re
 
 # Cedar Backup modules
 from CedarBackup2.filesystem import FilesystemList
-from CedarBackup2.util import splitCommandLine, executeCommand, encodePath
+from CedarBackup2.util import resolveCommand, executeCommand
+from CedarBackup2.util import splitCommandLine, encodePath
 
 
 ########################################################################
@@ -703,7 +702,7 @@ class RemotePeer(object):
             try:
                os.remove(targetFile)
             except:
-               raise Exception("Internal error: target existed before it should.")
+               raise Exception("Error: collect indicator [%s] already exists!" % targetFile)
          try:
             RemotePeer._copyRemoteFile(self.remoteUser, self.localUser, self.name, 
                                        self._rcpCommand, self._rcpCommandList, 
@@ -735,23 +734,14 @@ class RemotePeer(object):
       @note: If you have user/group as strings, call the L{util.getUidGid} function
       to get the associated uid/gid as an ownership tuple.
 
-      @note: This method's behavior is UNIX-specific.  It depends on the
-      ability of L{tempfile.NamedTemporaryFile} to create files that can be
-      opened more than once.
-
       @param stageIndicator: Name of the indicator file to write
       @type stageIndicator: String representing name of a file in the collect directory
 
-      @raise ValueError: If collect directory is not a directory or does not exist 
       @raise ValueError: If a path cannot be encoded properly.
       @raise IOError: If there is an IO error creating the file.
       @raise OSError: If there is an OS error creating or changing permissions on the file
       """
       stageIndicator = encodePath(stageIndicator)
-      if not os.path.exists(self.collectDir) or not os.path.isdir(self.collectDir):
-         logger.debug("Collect directory [%s] is not a directory or does not exist on disk." % self.collectDir)
-         raise ValueError("Collect directory is not a directory or does not exist on disk.")
-      sourceFile = tempfile.NamedTemporaryFile(dir=self.workingDir)
       if stageIndicator is None:
          sourceFile = os.path.join(self.workingDir, DEF_STAGE_INDICATOR)
          targetFile = os.path.join(self.collectDir, DEF_STAGE_INDICATOR)
@@ -865,17 +855,21 @@ class RemotePeer(object):
       """
       beforeSet = RemotePeer._getDirContents(targetDir)
       if localUser is not None:
-         if os.getuid() != 0:
-            raise IOError("Only root can remote copy as another user.")
+         try:
+            if os.getuid() != 0:
+               raise IOError("Only root can remote copy as another user.")
+         except AttributeError: pass
          actualCommand = "%s %s@%s:%s/* %s" % (rcpCommand, remoteUser, remoteHost, sourceDir, targetDir)
-         result = executeCommand(SU_COMMAND, [localUser, "-c", actualCommand])[0]
+         command = resolveCommand(SU_COMMAND)
+         result = executeCommand(command, [localUser, "-c", actualCommand])[0]
          if result != 0:
             raise IOError("Error (%d) copying files from remote host as local user [%s]." % (result, localUser))
       else:
          copySource = "%s@%s:%s/*" % (remoteUser, remoteHost, sourceDir)
-         result = executeCommand(rcpCommandList, [copySource, targetDir])[0]
+         command = resolveCommand(rcpCommandList)
+         result = executeCommand(command, [copySource, targetDir])[0]
          if result != 0:
-            raise IOError("Error (%d) copying files from remote host (no local user)." % result)
+            raise IOError("Error (%d) copying files from remote host (using no local user)." % result)
       afterSet = RemotePeer._getDirContents(targetDir)
       if len(afterSet) == 0:
          raise IOError("Did not copy any files from remote peer.")
@@ -954,17 +948,21 @@ class RemotePeer(object):
          if os.path.exists(targetFile):
             raise IOError("Target file [%s] already exists." % targetFile)
       if localUser is not None:
-         if os.getuid() != 0:
-            raise IOError("Only root can remote copy as another user.")
+         try:
+            if os.getuid() != 0:
+               raise IOError("Only root can remote copy as another user.")
+         except AttributeError: pass
          actualCommand = "%s %s@%s:%s %s" % (rcpCommand, remoteUser, remoteHost, sourceFile.replace(" ", "\\ "), targetFile)
-         result = executeCommand(SU_COMMAND, [localUser, "-c", actualCommand])[0]
+         command = resolveCommand(SU_COMMAND) 
+         result = executeCommand(command, [localUser, "-c", actualCommand])[0]
          if result != 0:
             raise IOError("Error (%d) copying [%s] from remote host as local user [%s]." % (result, sourceFile, localUser))
       else:
          copySource = "%s@%s:%s" % (remoteUser, remoteHost, sourceFile.replace(" ", "\\ "))
-         result = executeCommand(rcpCommandList, [copySource, targetFile])[0]
+         command = resolveCommand(rcpCommandList)
+         result = executeCommand(command, [copySource, targetFile])[0]
          if result != 0:
-            raise IOError("Error (%d) copying [%s] from remote host (no local user)." % (result, sourceFile))
+            raise IOError("Error (%d) copying [%s] from remote host (using no local user)." % (result, sourceFile))
       if not os.path.exists(targetFile):
          raise IOError("Apparently unable to copy file from remote host.")
       if ownership is not None:
@@ -1021,16 +1019,20 @@ class RemotePeer(object):
          if os.path.exists(targetFile):
             raise IOError("Target file [%s] already exists." % targetFile)
       if localUser is not None:
-         if os.getuid() != 0:
-            raise IOError("Only root can remote copy as another user.")
+         try:
+            if os.getuid() != 0:
+               raise IOError("Only root can remote copy as another user.")
+         except AttributeError: pass
          actualCommand = '%s "%s" "%s@%s:%s"' % (rcpCommand, sourceFile, remoteUser, remoteHost, targetFile)
-         result = executeCommand(SU_COMMAND, [localUser, "-c", actualCommand])[0]
+         command = resolveCommand(SU_COMMAND)
+         result = executeCommand(command, [localUser, "-c", actualCommand])[0]
          if result != 0:
             raise IOError("Error (%d) copying [%s] to remote host as local user [%s]." % (result, sourceFile, localUser))
       else:
          copyTarget = "%s@%s:%s" % (remoteUser, remoteHost, targetFile.replace(" ", "\\ "))
-         result = executeCommand(rcpCommandList, [sourceFile.replace(" ", "\\ "), copyTarget])[0]
+         command = resolveCommand(rcpCommandList)
+         result = executeCommand(command, [sourceFile.replace(" ", "\\ "), copyTarget])[0]
          if result != 0:
-            raise IOError("Error (%d) copying [%s] to remote host (no local user)." % (result, sourceFile))
+            raise IOError("Error (%d) copying [%s] to remote host (using no local user)." % (result, sourceFile))
    _pushLocalFile = staticmethod(_pushLocalFile)
 
